@@ -10,11 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gst, GstPbutils, GLib
-
-from gettext import gettext as _
-
-from lollypop.define import Lp
+from gi.repository import Gst, GstPbutils
 
 
 class Codecs:
