@@ -25,7 +25,7 @@ from lollypop.utils import get_ip
 
 
 class MpdHandler(socketserver.StreamRequestHandler):
-    # Delayed signal
+    # Delayed signals
     _PLCHANGES = ["add", "delete", "clear", "deleteid", "move",
                   "moveid", "load", "playlistadd"]
 
@@ -34,6 +34,7 @@ class MpdHandler(socketserver.StreamRequestHandler):
             One function to handle them all
         """
         self.request.send("OK MPD 0.19.0\n".encode('utf-8'))
+        self._idle_thread = None
         while self.server.running:
             msg = ""
             try:
@@ -43,9 +44,11 @@ class MpdHandler(socketserver.StreamRequestHandler):
                 delayed = False
                 # Read commands
                 while True:
+                    print("True")
                     data = self.rfile.readline().strip().decode("utf-8")
+                    print("False")
                     if len(data) == 0:
-                        raise IOError  # EOF
+                        raise IOError
                     if data == "command_list_ok_begin":
                         cmdlist = "list_ok"
                     elif data == "command_list_begin":
@@ -56,6 +59,8 @@ class MpdHandler(socketserver.StreamRequestHandler):
                         cmds.append(data)
                         if not cmdlist:
                             break
+                if not cmds:
+                    continue
                 try:
                     print(cmds, self)
                     for cmd in cmds:
@@ -65,20 +70,27 @@ class MpdHandler(socketserver.StreamRequestHandler):
                         if command in self._PLCHANGES:
                             delayed = True
                         call = getattr(self, '_%s' % command)
-                        msg += call(args)
-                        if cmdlist == "list_ok":
-                            msg += "list_OK\n"
+                        result = call(args)
+                        if result is None:
+                            msg = None
+                            break
+                        else:
+                            msg += result
+                            if cmdlist == "list_ok":
+                                msg += "list_OK\n"
+                    if msg is None:
+                        continue
                 except Exception as e:
                     print("MpdHandler::handle(): ", cmds, e)
-                    raise
                 msg += "OK\n"
-                self.request.send(msg.encode("utf-8"))
+                self.wfile.write(msg.encode("utf-8"))
                 print(msg.encode("utf-8"), self)
                 if delayed:
                     GLib.idle_add(Lp().playlists.emit,
                                   'playlist-changed',
                                   Type.MPD)
-            except:
+            except Exception as e:
+                print(e)
                 break
 
     def _add(self, cmd_args):
@@ -90,6 +102,10 @@ class MpdHandler(socketserver.StreamRequestHandler):
         """
         tracks = []
         arg = self._get_args(cmd_args)[0]
+        try:
+            arg = GLib.filename_from_uri(arg)[0]
+        except:
+            pass
         track_id = Lp().tracks.get_id_by_path(arg)
         if track_id is None:
             path = ""
@@ -109,6 +125,21 @@ class MpdHandler(socketserver.StreamRequestHandler):
         Lp().playlists.add_tracks(Type.MPD, tracks, False)
         return ""
 
+    def _addid(self, cmd_args):
+        """
+            Add track to mpd playlist at pos
+            @syntax add filepath
+            @param args as str
+            @return msg as str
+        """
+        arg = self._get_args(cmd_args)[0]
+        self._add(cmd_args)
+        try:
+            arg = GLib.filename_from_uri(arg)[0]
+        except:
+            pass
+        return "Id: %s" % Lp().tracks.get_id_by_path(arg)
+
     def _clear(self, cmd_args):
         """
             Clear mpd playlist
@@ -274,6 +305,17 @@ class MpdHandler(socketserver.StreamRequestHandler):
             @param args as str
             @return msg as str
         """
+        if self._idle_thread is None:
+            self._idle_thread = threading.Thread(target=self._idle_threaded,
+                                                 args=(cmd_args,))
+            self._idle_thread.daemon = True
+            self._idle_thread.start()
+        return None
+
+    def _idle_threaded(self, cmd_args):
+        """
+            Same as previous, thread safe
+        """
         msg = ''
         args = self._get_args(cmd_args)
         if args:
@@ -283,7 +325,6 @@ class MpdHandler(socketserver.StreamRequestHandler):
         else:
             self.server.idle_wanted_strings = ["stored_playlist",
                                                "player", "playlist", "options"]
-        self.request.settimeout(0)
         self.server.event.clear()
         # We handle notifications directly if something in queue
         if not self.server.idle_strings:
@@ -291,9 +332,16 @@ class MpdHandler(socketserver.StreamRequestHandler):
         # Handle new notifications
         for string in self.server.idle_strings:
             msg += "changed: %s\n" % string
+        if msg != "":
+            msg += "OK\n"
+            try:
+                self.request.send(msg.encode("utf-8"))
+            except:
+                pass
+            print("IDLE", msg.encode("utf-8"), self)
+        self.server.idle_wanted_strings = []
         self.server.idle_strings = []
-        self.request.settimeout(10)
-        return msg
+        self._idle_thread = None
 
     def _noidle(self, cmd_args):
         """
@@ -302,9 +350,18 @@ class MpdHandler(socketserver.StreamRequestHandler):
             @param args as str
             @return msg as str
         """
+        msg = ""
+        # Handle new notifications
+        for string in self.server.idle_strings:
+            msg += "changed: %s\n" % string
+        msg += "OK\n"
+        self.request.send(msg.encode("utf-8"))
+        print("NOIDLE", msg.encode("utf-8"), self)
+        self.server.idle_wanted_strings = []
         self.server.idle_strings = []
+        self._idle_thread = None
         self.server.event.set()
-        return ""
+        return None
 
     def _list(self, cmd_args):
         """
@@ -325,7 +382,6 @@ class MpdHandler(socketserver.StreamRequestHandler):
         genre = genre_id = None
         date = ''
         while i < len(args) - 1:
-            print(args[i], i)
             if args[i].lower() == 'album':
                 if i % 2:
                     album = args[i+1]
@@ -1017,16 +1073,17 @@ class MpdHandler(socketserver.StreamRequestHandler):
         """
         args = self._get_args(cmd_args)
         msg = ""
-        if args[0].find("get song ") != -1 and\
-                args[2].find("rating") != -1:
-            track_id = Lp().tracks.get_id_by_path(args[1])
+        print(args)
+        if args[0] == "get" and args[1] == "song" and\
+                args[3] == "rating":
+            track_id = Lp().tracks.get_id_by_path(args[2])
             track = Track(track_id)
-            msg = "sticker: rating=%s\n" % int(track.get_popularity()*2)
-        elif args[0].find("set song") != -1 and\
-                args[2].find("rating") != -1:
-            track_id = Lp().tracks.get_id_by_path(args[1])
+            msg = "sticker: rating=%s\n" % int((track.get_popularity()-0.5)*2)
+        elif args[0] == "set" and args[1] == "song" and\
+                args[3] == "rating":
+            track_id = Lp().tracks.get_id_by_path(args[2])
             track = Track(track_id)
-            track.set_popularity(int(args[3])/2)
+            track.set_popularity(int(args[4])/2)
         return msg
 
     def _stop(self, cmd_args):
@@ -1083,7 +1140,7 @@ class MpdHandler(socketserver.StreamRequestHandler):
         else:
             track = Track(track_id)
             if index == Type.NONE:
-                index = 0
+                index = 1
                 if Lp().player.is_party():
                     tracks_ids = [Lp().player.prev_track.id,
                                   Lp().player.current_track.id,
@@ -1092,7 +1149,7 @@ class MpdHandler(socketserver.StreamRequestHandler):
                 else:
                     tracks_ids = Lp().playlists.get_tracks_ids(Type.MPD)
                     try:
-                        index = tracks_ids.index(track_id)
+                        index = tracks_ids.index(track_id) + 1
                     except:
                         pass
             msg = "file: %s\nArtist: %s\nAlbum: %s\nAlbumArtist: %s\
@@ -1107,7 +1164,7 @@ class MpdHandler(socketserver.StreamRequestHandler):
                      track.duration,
                      track.id,
                      index,
-                     track.position)
+                     index)
         return msg
 
     def _get_status(self):
@@ -1129,12 +1186,19 @@ class MpdHandler(socketserver.StreamRequestHandler):
             @param args as str
             @return args as [str]
         """
-        splited = args.split('"')
         ret = []
-        for arg in splited:
-            if len(arg.replace(' ', '')) == 0:
+        for arg in args.split('"'):
+            # Ignore bad args
+            if arg.strip() == "":
                 continue
-            ret.append(arg)
+            # Some client do not put "" for all args
+            elif len(arg) > 0 and (arg[-1] == " " or
+                                   arg[0] == " "):
+                for subarg in arg.split(' '):
+                    if subarg.strip() != "":
+                        ret.append(subarg)
+            else:
+                ret.append(arg)
         return ret
 
     def _find_tracks(self, cmd_args):
@@ -1207,10 +1271,7 @@ class MpdServer(socketserver.ThreadingMixIn, socketserver.TCPServer):
         self.idle_strings = []
         try:
             # Set initial playlist version
-            self.playlist[self.playlist_version] = []
-            for track_id in Lp().playlists.get_tracks_ids(Type.MPD):
-                self.playlist[
-                        self.playlist_version].append(track_id)
+            self.playlist[0] = []
             socketserver.TCPServer.allow_reuse_address = True
             # Get ip for interface
             ip = ""
