@@ -80,14 +80,17 @@ class BinPlayer(ReplayGainPlayer, BasePlayer):
             state = Gst.State.NULL
         return state
 
-    def load(self, track):
+    def load(self, track, notify=True):
         """
             Stop current track, load track id and play it
             @param track as Track
         """
-        self._stop()
+        self._playbin.set_state(Gst.State.NULL)
         if self._load_track(track):
-            self.play()
+            if notify:
+                self.play()
+            else:
+                self._playbin.set_state(Gst.State.PLAYING)
 
     def play(self):
         """
@@ -112,7 +115,7 @@ class BinPlayer(ReplayGainPlayer, BasePlayer):
         """
             Change player state to STOPPED
         """
-        self._stop()
+        self._playbin.set_state(Gst.State.NULL)
         self.emit("status-changed")
 
     def play_pause(self):
@@ -173,17 +176,10 @@ class BinPlayer(ReplayGainPlayer, BasePlayer):
 #######################
 # PRIVATE             #
 #######################
-    def _stop(self):
-        """
-            Stop current track (for track change)
-        """
-        self._playbin.set_state(Gst.State.NULL)
-
-    def _load_track(self, track, sql=None):
+    def _load_track(self, track):
         """
             Load track
             @param track as Track
-            @param sql as sqlite cursor
             @return False if track not loaded
         """
         stop = False
@@ -276,12 +272,13 @@ class BinPlayer(ReplayGainPlayer, BasePlayer):
             @param message as Gst.Message
         """
         debug("Error playing: %s" % self.current_track.uri)
+        Lp().window.pulse(False)
         if self._codecs.is_missing_codec(message):
             self._codecs.install()
-            Lp.scanner.stop()
-        elif Lp.notify is not None:
-            Lp.notify.send(_("File doesn't exist: %s") %
-                           self.current_track.uri)
+            Lp().scanner.stop()
+        elif Lp().notify is not None:
+            Lp().notify.send(_("File doesn't exist: %s") %
+                             self.current_track.uri)
         self.stop()
         self.emit('current-changed')
         return True
@@ -313,26 +310,22 @@ class BinPlayer(ReplayGainPlayer, BasePlayer):
         finished_start_time = self._start_time
         if self.next_track.id is not None:
             self._load_track(self.next_track)
-        # We are in a thread, we need to create a new cursor
-        sql = Lp.db.get_cursor()
         # Increment popularity
-        if not Lp.scanner.is_locked():
-            Lp.tracks.set_more_popular(finished.id, sql)
-            Lp.albums.set_more_popular(finished.album_id, sql)
+        if not Lp().scanner.is_locked():
+            Lp().tracks.set_more_popular(finished.id)
+            Lp().albums.set_more_popular(finished.album_id)
         # Scrobble on lastfm
-        if Lp.lastfm is not None:
+        if Lp().lastfm is not None:
             if finished.album_artist_id == Type.COMPILATIONS:
                 artist = finished.artist
             else:
                 artist = finished.album_artist
             if time() - finished_start_time > 30:
-                Lp.lastfm.scrobble(artist,
-                                   finished.album_name,
-                                   finished.title,
-                                   int(finished_start_time),
-                                   int(finished.duration))
-
-        sql.close()
+                Lp().lastfm.scrobble(artist,
+                                     finished.album_name,
+                                     finished.title,
+                                     int(finished_start_time),
+                                     int(finished.duration))
 
     def _on_stream_start(self, bus, message):
         """
@@ -345,15 +338,15 @@ class BinPlayer(ReplayGainPlayer, BasePlayer):
         debug("Player::_on_stream_start(): %s" % self.current_track.uri)
         self.emit('current-changed')
         # Update now playing on lastfm
-        if Lp.lastfm is not None and self.current_track.id >= 0:
+        if Lp().lastfm is not None and self.current_track.id >= 0:
             if self.current_track.album_artist_id == Type.COMPILATIONS:
                 artist = self.current_track.artist
             else:
                 artist = self.current_track.album_artist
-                Lp.lastfm.now_playing(artist,
-                                      self.current_track.album_name,
-                                      self.current_track.title,
-                                      int(self.current_track.duration))
-        if not Lp.scanner.is_locked():
-            Lp.tracks.set_listened_at(self.current_track.id, int(time()))
+                Lp().lastfm.now_playing(artist,
+                                        self.current_track.album_name,
+                                        self.current_track.title,
+                                        int(self.current_track.duration))
+        if not Lp().scanner.is_locked():
+            Lp().tracks.set_listened_at(self.current_track.id, int(time()))
         self._handled_error = None
