@@ -17,6 +17,8 @@ from threading import Thread
 
 from lollypop.define import Lp, ArtSize, Type
 from lollypop.objects import Track, Album
+from lollypop.pop_menu import TrackMenuPopover, TrackMenu
+from lollypop.widgets_album_context import AlbumPopoverWidget
 
 
 class SearchRow(Gtk.ListBoxRow):
@@ -88,7 +90,6 @@ class SearchRow(Gtk.ListBoxRow):
             @param button as Gtk.Button
         """
         Lp().window.show_playlist_manager(self.id, None, not self.is_track)
-        self._parent.hide()
 
     def _on_queue_clicked(self, button):
         """
@@ -145,6 +146,7 @@ class SearchPopover(Gtk.Popover):
             @param parent as Gtk.Widget
         """
         Gtk.Popover.__init__(self)
+        self.set_position(Gtk.PositionType.BOTTOM)
         self.connect('map', self._on_map)
         self.connect('unmap', self._on_unmap)
         self._parent = parent
@@ -161,17 +163,23 @@ class SearchPopover(Gtk.Popover):
         self._new_btn = builder.get_object('new_btn')
 
         self._view = Gtk.ListBox()
+        self._view.connect("button-press-event", self._on_button_press)
         self._view.connect("row-activated", self._on_activate)
         self._view.show()
 
         builder.get_object('scrolled').add(self._view)
         self.add(builder.get_object('widget'))
 
+    def do_show(self):
+        """
+            Set widget size
+        """
         size_setting = Lp().settings.get_value('window-size')
         if isinstance(size_setting[1], int):
             self.set_size_request(400, size_setting[1]*0.7)
         else:
             self.set_size_request(400, 600)
+        Gtk.Popover.do_show(self)
 
 #######################
 # PRIVATE             #
@@ -314,7 +322,7 @@ class SearchPopover(Gtk.Popover):
                 track_id = object_id
             elif track_id is None:
                 track_id = tracks[0].id
-            GLib.idle_add(self._set_user_playlist, tracks, track_id)
+            GLib.idle_add(self._set_user_playlist_by_tracks, tracks, track_id)
 
     def _new_playlist(self):
         """
@@ -383,17 +391,6 @@ class SearchPopover(Gtk.Popover):
         t.daemon = True
         t.start()
 
-    def _on_activate(self, widget, row):
-        """
-            Play searched item when selected
-            If item is an album, play first track
-            @param widget as Gtk.ListBox
-            @param row as SearchRow
-        """
-        t = Thread(target=self._play_search, args=(row.id, row.is_track))
-        t.daemon = True
-        t.start()
-
     def _on_play_btn_clicked(self, button):
         """
             Start playback base on current search
@@ -411,3 +408,38 @@ class SearchPopover(Gtk.Popover):
         t = Thread(target=self._new_playlist)
         t.daemon = True
         t.start()
+
+    def _on_activate(self, widget, row):
+        """
+            Play searched item when selected
+            If item is an album, play first track
+            @param widget as Gtk.ListBox
+            @param row as SearchRow
+        """
+        t = Thread(target=self._play_search, args=(row.id, row.is_track))
+        t.daemon = True
+        t.start()
+
+    def _on_button_press(self, widget, event):
+        """
+            Store pressed button
+            @param widget as Gtk.ListBox
+            @param event as Gdk.EventButton
+        """
+        if event.button != 1 and\
+           Gtk.get_minor_version() > 16:
+            rect = widget.get_allocation()
+            rect.x = event.x
+            rect.y = event.y
+            rect.width = rect.height = 1
+            row = widget.get_row_at_y(event.y)
+            if row.is_track:
+                popover = TrackMenuPopover(row.id, TrackMenu(row.id))
+                popover.set_relative_to(widget)
+                popover.set_pointing_to(rect)
+                popover.show()
+            else:
+                popover = AlbumPopoverWidget(row.id, None)
+                popover.set_relative_to(widget)
+                popover.set_pointing_to(rect)
+                popover.show()
