@@ -65,26 +65,34 @@ class MtpSync:
             sleep(5)
             self._retry(func, args, t-1)
 
-    def _get_children_uris(self, uri):
+    def _get_tracks_files(self):
         """
             Return children uris for uri
-            @param uri as str
             @return [str]
         """
         children = []
-        dir_uris = [uri]
+        dir_uris = [self._uri+'/tracks/']
         while dir_uris:
             uri = dir_uris.pop(0)
-            d = Gio.File.new_for_uri(uri)
+            album_name = uri.replace(self._uri+"/tracks/", "")
+            album = GLib.uri_escape_string(album_name,
+                                           "",
+                                           False)
+            d = Gio.File.new_for_uri(self._uri+"/tracks/"+album)
             infos = d.enumerate_children(
                 'standard::name,standard::type',
                 Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
                 None)
             for info in infos:
                 if info.get_file_type() == Gio.FileType.DIRECTORY:
-                    dir_uris.append(uri+'/'+info.get_name())
+                    dir_uris.append(uri+info.get_name())
                 else:
-                    children.append(uri+'/'+info.get_name())
+                    track = GLib.uri_escape_string(info.get_name(),
+                                                   "",
+                                                   False)
+                    children.append("%s/tracks/%s/%s" % (self._uri,
+                                                         album,
+                                                         track))
         return children
 
     def _sync(self, playlists):
@@ -111,7 +119,7 @@ class MtpSync:
 
             # Old tracks
             try:
-                children = self._get_children_uris(self._uri+'/tracks')
+                children = self._get_tracks_files()
                 self._total += len(children)
             except:
                 pass
@@ -178,16 +186,16 @@ class MtpSync:
                     self._in_thread = False
                     return
                 track = Track(track_id)
-                album_name = GLib.uri_escape_string(track.album_name,
+                album_name = GLib.uri_escape_string(track.album_name.lower(),
                                                     "",
                                                     False)
-                artist_name = GLib.uri_escape_string(track.artist,
+                artist_name = GLib.uri_escape_string(track.artist.lower(),
                                                      "",
                                                      False)
                 on_device_album_uri = "%s/tracks/%s_%s" %\
                                       (self._uri,
-                                       artist_name.lower(),
-                                       album_name.lower())
+                                       artist_name,
+                                       album_name)
 
                 d = Gio.File.new_for_uri(on_device_album_uri)
                 if not d.query_exists(None):
@@ -261,16 +269,16 @@ class MtpSync:
                 self._in_thread = False
                 return
             track = Track(track_id)
-            album_name = GLib.uri_escape_string(track.album_name,
+            album_name = GLib.uri_escape_string(track.album_name.lower(),
                                                 "",
                                                 False)
-            artist_name = GLib.uri_escape_string(track.artist,
+            artist_name = GLib.uri_escape_string(track.artist.lower(),
                                                  "",
                                                  False)
             track_path = Lp().tracks.get_path(track_id)
             album_uri = "%s/tracks/%s_%s" % (self._uri,
-                                             artist_name.lower(),
-                                             album_name.lower())
+                                             artist_name,
+                                             album_name)
             track_name = GLib.uri_escape_string(GLib.basename(track_path),
                                                 "",
                                                 False)
@@ -283,7 +291,7 @@ class MtpSync:
             dst_uri = "%s/%s_%s" % (album_uri, mtime, track_name)
             track_uris.append(dst_uri)
 
-        on_mtp_files = self._get_children_uris(self._uri+'/tracks')
+        on_mtp_files = self._get_tracks_files()
 
         # Delete file on device and not in playlists
         for uri in on_mtp_files:
