@@ -15,6 +15,9 @@ from gi.repository import Gio
 from gettext import gettext as _
 from threading import Thread
 import os
+import socket
+import fcntl
+import struct
 
 from lollypop.define import Lp, Type
 from lollypop.objects import Track
@@ -25,10 +28,21 @@ def debug(str):
         Print debug
         @param debug as str
     """
-    if Lp.debug is True:
+    if Lp().debug is True:
         print(str)
 
 
+def get_ip(interface):
+    """
+        Get ip address for interface
+    """
+    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    return socket.inet_ntoa(fcntl.ioctl(
+        s.fileno(),
+        0x8915,  # SIOCGIFADDR
+        struct.pack('256s', interface[:15].encode('utf-8')))[20:24])
+
+
 def is_unity():
     """
         Return True if desktop is Unity
@@ -130,8 +144,8 @@ def is_loved(track_id):
         Check if object is in loved playlist
         @return bool
     """
-    return Lp.playlists.exists_track(Type.LOVED,
-                                     track_id)
+    return Lp().playlists.exists_track(Type.LOVED,
+                                       track_id)
 
 
 def set_loved(track_id, loved):
@@ -140,26 +154,24 @@ def set_loved(track_id, loved):
         @param track_id
         @param loved Add to loved playlist if `True`; remove if `False`
     """
-    sql = Lp.playlists.get_cursor()
     if not is_loved(track_id):
         if loved:
-            Lp.playlists.add_tracks(Type.LOVED,
-                                    [Track(track_id)], sql)
-            if Lp.lastfm is not None:
+            Lp().playlists.add_tracks(Type.LOVED,
+                                      [Track(track_id)])
+            if Lp().lastfm is not None:
                 t = Thread(target=_set_loved_on_lastfm, args=(track_id,
                                                               True))
                 t.daemon = True
                 t.start()
     else:
         if not loved:
-            Lp.playlists.remove_tracks(Type.LOVED,
-                                       [Track(track_id)], sql)
-            if Lp.lastfm is not None:
+            Lp().playlists.remove_tracks(Type.LOVED,
+                                         [Track(track_id)])
+            if Lp().lastfm is not None:
                 t = Thread(target=_set_loved_on_lastfm, args=(track_id,
                                                               False))
                 t.daemon = True
                 t.start()
-    sql.close()
 
 
 def _set_loved_on_lastfm(track_id, loved):
@@ -168,20 +180,19 @@ def _set_loved_on_lastfm(track_id, loved):
         @param track_id
         @param loved Add to loved playlist if `True`; remove if `False`
     """
-    sql = Lp.db.get_cursor()
     # Love the track on lastfm
     if Gio.NetworkMonitor.get_default().get_network_available() and\
-            Lp.lastfm.is_auth():
-        title = Lp.tracks.get_name(track_id, sql)
-        album_id = Lp.tracks.get_album_id(track_id, sql)
-        artist_id = Lp.albums.get_artist_id(album_id, sql)
+            Lp().lastfm.is_auth():
+        title = Lp().tracks.get_name(track_id)
+        album_id = Lp().tracks.get_album_id(track_id)
+        artist_id = Lp().albums.get_artist_id(album_id)
 
         if artist_id == Type.COMPILATIONS:
-            artist = Lp.tracks.get_artist_names(track_id, sql)
+            artist = Lp().tracks.get_artist_names(track_id)
         else:
-            artist = Lp.artists.get_name(artist_id, sql)
+            artist = Lp().artists.get_name(artist_id)
 
         if loved:
-            Lp.lastfm.love(artist, title)
+            Lp().lastfm.love(artist, title)
         else:
-            Lp.lastfm.unlove(artist, title)
+            Lp().lastfm.unlove(artist, title)
