@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, GObject, Gdk
+from gi.repository import Gtk, GLib, GObject, Gdk, Pango
 
 from cgi import escape
 from gettext import gettext as _
@@ -56,6 +56,8 @@ class AlbumWidget:
             Update cover for album id id needed
             @param album id as int
         """
+        if self._cover is None:
+            return
         surface = Lp().art.get_album_artwork(
                             self._album,
                             ArtSize.BIG * self._cover.get_scale_factor())
@@ -66,6 +68,8 @@ class AlbumWidget:
         """
             Update widget state
         """
+        if self._album is None:
+            return
         selected = self._album.id == Lp().player.current_track.album.id
         if selected != self._selected:
             if selected:
@@ -145,43 +149,92 @@ class AlbumWidget:
         self._cover.get_style_context().remove_class('hovereffect')
 
 
-class AlbumSimpleWidget(Gtk.Bin, AlbumWidget):
+class AlbumSimpleWidget(Gtk.Frame, AlbumWidget):
     """
         Album widget showing cover, artist and title
     """
 
-    def __init__(self, album_id):
+    def __init__(self, album_id, width=0, height=0):
         """
             Init simple album widget
             @param album id as int
+            @param width request as int
+            @param height request as int
         """
-        Gtk.Bin.__init__(self)
-        AlbumWidget.__init__(self, album_id)
-        builder = Gtk.Builder()
-        builder.add_from_resource('/org/gnome/Lollypop/AlbumSimpleWidget.ui')
-        builder.connect_signals(self)
-        self._widget = builder.get_object('widget')
-        self._cover = builder.get_object('cover')
-        self._color = builder.get_object('color')
+        # We do not use Gtk.Builder for speed reasons
+        Gtk.Frame.__init__(self)
+        self.set_shadow_type(Gtk.ShadowType.NONE)
+        self.get_style_context().add_class('loading')
+        self._album_id = album_id
+        self._album = None
+        self._width = width
+        if width != 0 and height != 0:
+            self.set_size_request(width, height)
+
+    def init_widget(self):
+        """
+            Init widget content
+        """
+        self.get_style_context().remove_class('loading')
+        AlbumWidget.__init__(self, self._album_id)
+        self._widget = Gtk.EventBox()
+        self._widget.connect('enter-notify-event', self._on_enter_notify)
+        self._widget.connect('leave-notify-event', self._on_leave_notify)
         self._widget.set_property('has-tooltip', True)
-        self._title_label = builder.get_object('title')
-        self._title_label.set_text(self._album.name)
-        self._artist_label = builder.get_object('artist')
+        grid = Gtk.Grid()
+        grid.set_orientation(Gtk.Orientation.VERTICAL)
+        grid1 = Gtk.Grid()
+        grid1.get_style_context().add_class('white')
+        frame = Gtk.Frame()
+        frame.get_style_context().add_class('cover-frame')
+        self._color = Gtk.Frame()
+        self._color.get_style_context().add_class('cover-frame-border')
+        self._cover = Gtk.Image()
+        self._title_label = Gtk.Label()
+        self._title_label.set_ellipsize(Pango.EllipsizeMode.END)
+        self._title_label.set_property('halign', Gtk.Align.CENTER)
+        self._title_label.set_markup("<b>"+escape(self._album.name)+"</b>")
+        self._artist_label = Gtk.Label()
+        self._artist_label.set_ellipsize(Pango.EllipsizeMode.END)
+        self._artist_label.set_property('halign', Gtk.Align.CENTER)
         self._artist_label.set_text(self._album.artist_name)
+        self._artist_label.get_style_context().add_class('dim-label')
+        self._widget.add(grid)
+        grid.add(frame)
+        grid.add(self._title_label)
+        grid.add(self._artist_label)
+        frame.add(self._color)
+        self._color.add(grid1)
+        grid1.add(self._cover)
         self.add(self._widget)
         self.set_cover()
         self.update_state()
         self.set_property('halign', Gtk.Align.CENTER)
         self.set_property('valign', Gtk.Align.START)
+        self.show_all()
+
+    def get_id(self):
+        """
+            Return album id
+            @return int
+        """
+        return self._album_id
 
     def do_get_preferred_width(self):
         """
-            Set maximum width
+            Return preferred width
+            @return (int, int)
         """
-        widths = self._cover.get_preferred_width()
-        return (widths[0] + 8, widths[1] + 8)
+        if self._width != 0:
+            return (self._width, self._width)
+        else:
+            widths = self._cover.get_preferred_width()
+            return (widths[0] + 8, widths[1] + 8)
 
     def update_cursor(self):
+        """
+            Update album cursor
+        """
         if Lp().settings.get_value('auto-play'):
             AlbumWidget.update_cursor(self, Gdk.CursorType.HAND1)
         else:
